pub enum ParamKind {
    Bool(bool),
    I8(i8),
    U8(u8),
    I16(i16),
    U16(u16),
    I32(i32),
    U32(u32),
    Float(f32),
    Hash(Hash40),
    Str(String),
    List(ParamList),
    Struct(ParamStruct),
}
The central data structure to param files and params. Similar to tree-like recursive data formats such as JSON.

Variants

Bool(bool)

I8(i8)

U8(u8)

I16(i16)

U16(u16)

I32(i32)

U32(u32)

Float(f32)

Hash(Hash40)

Str(String)

List(ParamList)

Struct(ParamStruct)

Implementations

Attempts to convert an owned param into the contained value. Returns an error if the contained value is not the expected type.

Attempts to convert a param by reference into a reference of the contained value. Returns an error if the contained value is not the expected type.

Attempts to convert a param by mutable reference into a mutable reference of the contained value. Returns an error if the contained value is not the expected type.

Converts an owned param into a HashMap, indexing into the contained params. Panics if the param was not a ParamKind::Struct.

Converts a reference to a param into a HashMap, indexing into references to the contained params. Panics if the param was not a ParamKind::Struct.

Converts a mutable reference to a param into a HashMap, indexing into mutable references to the contained params. Panics if the param was not a ParamKind::Struct.