pub struct StructData {
    pub position: u64,
    pub len: u32,
    pub ref_offset: u32,
}
Information read from a struct to facilitate reading child params

Fields

position: u64len: u32ref_offset: u32

Implementations

Moves the reader to the child param with the provided hash and reads the param fulfilling the Prc trait.