Struct prc::param::ParamStruct
source · [−]Expand description
A list of key-value pairs of params. Acts essentially like a hash-map, but is presented in list form to preserve key order, as well as to handle rare cases where a key may be duplicated. Keys are hashed strings, represented by the Hash40 type.
Tuple Fields
0: Vec<(Hash40, ParamKind)>Trait Implementations
sourceimpl Clone for ParamStruct
impl Clone for ParamStruct
sourcefn clone(&self) -> ParamStruct
fn clone(&self) -> ParamStruct
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for ParamStruct
impl Debug for ParamStruct
sourceimpl Default for ParamStruct
impl Default for ParamStruct
sourcefn default() -> ParamStruct
fn default() -> ParamStruct
Returns the “default value” for a type. Read more
sourceimpl<'de> Deserialize<'de> for ParamStruct
impl<'de> Deserialize<'de> for ParamStruct
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl From<ParamStruct> for ParamKind
impl From<ParamStruct> for ParamKind
sourcefn from(v: ParamStruct) -> ParamKind
fn from(v: ParamStruct) -> ParamKind
Converts to this type from the input type.
sourceimpl PartialEq<ParamStruct> for ParamStruct
impl PartialEq<ParamStruct> for ParamStruct
sourcefn eq(&self, other: &ParamStruct) -> bool
fn eq(&self, other: &ParamStruct) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &ParamStruct) -> bool
fn ne(&self, other: &ParamStruct) -> bool
This method tests for !=.
sourceimpl Serialize for ParamStruct
impl Serialize for ParamStruct
sourceimpl<'a> TryFrom<&'a ParamKind> for &'a ParamStruct
impl<'a> TryFrom<&'a ParamKind> for &'a ParamStruct
sourceimpl<'a> TryFrom<&'a mut ParamKind> for &'a mut ParamStruct
impl<'a> TryFrom<&'a mut ParamKind> for &'a mut ParamStruct
sourceimpl TryFrom<ParamKind> for ParamStruct
impl TryFrom<ParamKind> for ParamStruct
impl StructuralPartialEq for ParamStruct